@@ -13,8 +13,8 @@
 G_BEGIN_DECLS
 
 #define SOUP_MAJOR_VERSION (2)
-#define SOUP_MINOR_VERSION (44)
-#define SOUP_MICRO_VERSION (2)
+#define SOUP_MINOR_VERSION (46)
+#define SOUP_MICRO_VERSION (0)
 
 #define SOUP_CHECK_VERSION(major, minor, micro) \
     (SOUP_MAJOR_VERSION > (major) || \
@@ -47,6 +47,7 @@ gboolean soup_check_version     (guint major,
 #define SOUP_VERSION_2_40 (SOUP_ENCODE_VERSION (2, 40))
 #define SOUP_VERSION_2_42 (SOUP_ENCODE_VERSION (2, 42))
 #define SOUP_VERSION_2_44 (SOUP_ENCODE_VERSION (2, 44))
+#define SOUP_VERSION_2_46 (SOUP_ENCODE_VERSION (2, 46))
 
 /* evaluates to the current stable version; for development cycles,
  * this means the next stable target
@@ -241,6 +242,20 @@ gboolean soup_check_version     (guint major,
 # define SOUP_AVAILABLE_IN_2_44
 #endif
 
+#if SOUP_VERSION_MIN_REQUIRED >= SOUP_VERSION_2_46
+# define SOUP_DEPRECATED_IN_2_46                GLIB_DEPRECATED
+# define SOUP_DEPRECATED_IN_2_46_FOR(f)         GLIB_DEPRECATED_FOR(f)
+#else
+# define SOUP_DEPRECATED_IN_2_46
+# define SOUP_DEPRECATED_IN_2_46_FOR(f)
+#endif
+
+#if SOUP_VERSION_MAX_ALLOWED < SOUP_VERSION_2_46
+# define SOUP_AVAILABLE_IN_2_46                 GLIB_UNAVAILABLE(2, 46)
+#else
+# define SOUP_AVAILABLE_IN_2_46
+#endif
+
 G_END_DECLS
 
 #endif /* SOUP_VERSION_H */
